/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.user.associated.data.web.internal.portlet.action;

import com.liferay.portal.kernel.model.User;
import com.liferay.portal.kernel.portlet.bridges.mvc.MVCActionCommand;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.user.associated.data.anonymizer.UADAnonymizer;
import com.liferay.user.associated.data.constants.UserAssociatedDataPortletKeys;
import com.liferay.user.associated.data.web.internal.util.UADAnonymizerHelper;
import com.liferay.user.associated.data.web.internal.util.UADApplicationSummaryHelper;

import java.util.List;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Drew Brokke
 */
@Component(
	immediate = true,
	property = {
		"javax.portlet.name=" + UserAssociatedDataPortletKeys.USER_ASSOCIATED_DATA,
		"mvc.command.name=/anonymize_application_uad_entities"
	},
	service = MVCActionCommand.class
)
public class AnonymizeApplicationUADEntitiesMVCActionCommand
	extends BaseUADMVCActionCommand {

	@Override
	protected void doProcessAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws Exception {

		String applicationKey = ParamUtil.getString(
			actionRequest, "applicationKey");

		List<UADAnonymizer> uadAnonymizers =
			_uadApplicationSummaryHelper.getApplicationUADAnonymizers(
				applicationKey);

		for (UADAnonymizer uadAnonymizer : uadAnonymizers) {
			User selectedUser = getSelectedUser(actionRequest);

			User anonymousUser = _uadAnonymizerHelper.getAnonymousUser(
				selectedUser.getCompanyId());

			uadAnonymizer.autoAnonymizeAll(
				selectedUser.getUserId(), anonymousUser);
		}
	}

	@Reference
	private UADAnonymizerHelper _uadAnonymizerHelper;

	@Reference
	private UADApplicationSummaryHelper _uadApplicationSummaryHelper;

}